<?php

function rsvpmaker_to_stripe ($rsvp) {
	global $post;
	$vars['description'] = $post->post_title;
	$vars['name'] = $rsvp['first'].' '.$rsvp['last'];
	if(isset($_GET['rsvp']))
		$vars['rsvp_id'] = $_GET['rsvp'];
	else	
		$vars['rsvp_id'] = $rsvp['id'];
	$include = array('amount','rsvp_id','email','event');
	foreach($rsvp as $index => $value)
		if(in_array($index,$include))
			$vars[$index] = $value;
	// transform
	return rsvpmaker_stripe_form($vars);
}

function rsvpmaker_stripe_form($vars, $show = false) {
global $post, $rsvp_options;
ob_start();
require_once('stripe-php/init.php');

$public = get_option('rsvpmaker_stripe_pk');
$secret = get_option('rsvpmaker_stripe_sk');

if(strpos($public,'test'))
	$vars = array('test' => 'TEST TRANSACTION')+$vars;
	
\Stripe\Stripe::setApiKey($secret);

\Stripe\Stripe::setAppInfo(
  "WordPress RSVPMaker events management plugin",
  get_rsvpversion(),
  "https://rsvpmaker.com"
);

update_post_meta($post->ID,'stripe_temp',$vars);
$price = $vars['amount'] * 100;
?>
<p>
<form action="<?php echo get_permalink(); ?>" method="post">
  <script src="https://checkout.stripe.com/checkout.js" class="stripe-button"
          data-key="<?php echo $public; ?>"
		  data-email="<?php if(!empty($vars['email'])) echo $vars['email']; ?>"
          data-description="<?php echo htmlentities($vars['description']); ?>"
          data-amount="<?php echo $price; ?>"
          data-currency="<?php echo $rsvp_options["paypal_currency"]; ?>"
          data-locale="auto"></script>
</form>
</p>
<?php
$prefix = ($rsvp_options["paypal_currency"] == 'USD') ? '$' : '';
if($show)
	printf('<p>%s%s %s<br />%s</p>',$prefix,$vars['amount'],$rsvp_options["paypal_currency"],$vars["description"]);
if(strpos($public,'test') && !isset($_GET['hidetest']))
	printf('<p>%s</p>',__('Stripe is in TEST mode. To simulate a transaction, use:<br />Credit card 4111 1111 1111 1111<br />Any future date<br />Any three digit code.','rsvpmaker'));
return ob_get_clean();
}

add_filter('the_content','rsvpmaker_stripe_confirm',999);

function rsvpmaker_stripe_confirm($content) {
	if(isset($_GET['rsvpstripeconfirm']))
	{
		$confirm = get_option($_GET['rsvpstripeconfirm']);
		if(empty($confirm))
			$confirm = 'Error retrieving confirmation message';
		//delete_option($_GET['rsvpstripeconfirm']);
		return $confirm;
	}
	return $content;
}

add_filter('wp','rsvpmaker_stripe_charge_now',999);

function rsvpmaker_stripe_charge_now ($content)
{
if(!isset($_POST['stripeToken']))
	return $content;
global $post, $wpdb, $current_user;
$vars = get_post_meta($post->ID,'stripe_temp',true);
if(!empty($vars['paymentType']) && strpos($vars['paymentType'],'scription:'))
	return rsvpmaker_stripe_subscription($vars);
ob_start();
require_once('stripe-php/init.php');

$public = get_option('rsvpmaker_stripe_pk');
$secret = get_option('rsvpmaker_stripe_sk');

\Stripe\Stripe::setApiKey($secret);

\Stripe\Stripe::setAppInfo(
  "WordPress RSVPMaker events management plugin",
  get_rsvpversion(),
  "https://rsvpmaker.com"
);
	
$token  = $_POST['stripeToken'];
$email  = $_POST['stripeEmail'];
$success = false;
  $customer = \Stripe\Customer::create([
      'email' => $email,
      'source'  => $token,
  ]);
try {
  $charge = \Stripe\Charge::create([
      'customer' => $customer->id,
      'amount'   => $vars['amount'] * 100,
      'currency' => 'usd',
  ]);
$success = true;//only set on success
}
 catch(\Stripe\Error\Card $e) {
  // Since it's a decline, \Stripe\Error\Card will be caught
  $body = $e->getJsonBody();
  $err  = $body['error'];

  print('Status is:' . $e->getHttpStatus() . "\n");
  print('Type is:' . $err['type'] . "\n");
  print('Code is:' . $err['code'] . "\n");
  // param is '' in this case
  print('Param is:' . $err['param'] . "\n");
  print('Message is:' . $err['message'] . "\n");
} catch (\Stripe\Error\RateLimit $e) {
  // Too many requests made to the API too quickly
} catch (\Stripe\Error\InvalidRequest $e) {
  // Invalid parameters were supplied to Stripe's API
} catch (\Stripe\Error\Authentication $e) {
  // Authentication with Stripe's API failed
  // (maybe you changed API keys recently)
} catch (\Stripe\Error\ApiConnection $e) {
  // Network communication with Stripe failed
} catch (\Stripe\Error\Base $e) {
  // Display a very generic error to the user, and maybe send
  // yourself an email
} catch (Exception $e) {
  // Something else happened, completely unrelated to Stripe
}
if($success && !empty($charge->id)) // something is wrong
{
$vars['charge_id'] = $charge->id;
rsvpmaker_stripe_payment_log($vars);
echo '<h1>Thank you!</h1>';
foreach($vars as $index => $value)
	printf('<div>%s: %s</div>',$index,$value);
if(!empty($vars['rsvp_id']))
	{
		$rsvp_id = $vars['rsvp_id'];
		$paid = $vars['amount'];
		$invoice_id = get_post_meta($post->ID,'_open_invoice_'.$rsvp_id, true);
		if($invoice_id)
		{
		$charge = get_post_meta($post->ID,'_invoice_'.$rsvp_id, true);
		$paid_amounts = get_post_meta($post->ID,'_paid_'.$rsvp_id);
		if(!empty($paid_amounts))
		foreach($paid_amounts as $payment)
			$paid += $payment;
		$wpdb->query("UPDATE ".$wpdb->prefix."rsvpmaker SET amountpaid='$paid' WHERE id=$rsvp_id ");
		add_post_meta($post->ID,'_paid_'.$rsvp_id,$vars['amount']);
		delete_post_meta($post->ID,'_open_invoice_'.$rsvp_id);
		delete_post_meta($post->ID,'_invoice_'.$rsvp_id);
		}	
	}	
}
$confirmation = ob_get_clean();
$key = 'conf'.time().rand();
update_option($key,$confirmation);
$url = add_query_arg('rsvpstripeconfirm',$key,get_permalink($post->ID));
header('Location: '.$url);
exit();

}

function rsvpmaker_stripe_subscription($vars) {
global $post, $wpdb, $current_user,$rsvp_options;
ob_start();
require_once('stripe-php/init.php');

$public = get_option('rsvpmaker_stripe_pk');
$secret = get_option('rsvpmaker_stripe_sk');

\Stripe\Stripe::setApiKey($secret);
	
$token  = $_POST['stripeToken'];
$email  = $_POST['stripeEmail'];
$token  = $_POST['stripeToken'];
$customer = \Stripe\Customer::create([
      'email' => $email,
      'source'  => $token,
  ]);

$pt = explode(':',$vars['paymentType']);
print_r($pt);
$interval = $pt[1];
$slug = str_replace(' ','',$interval).'_'.$vars['amount'];
if($interval == '1 year')
	$parray = [
  "amount" => $vars['amount'] * 100,
  "interval" => "year",
  "product" => [
    "name" => "Recurring charge, ".get_bloginfo('name')
  ],
  "currency" => $rsvp_options['paypal_currency'],
  "id" => $slug
];
elseif($interval == '6 months')
	$parray = [
  "amount" => $vars['amount'] * 100,
  "interval" => "month",
  "interval_count" => 6,
  "product" => [
    "name" => "Recurring charge, ".get_bloginfo('name')
  ],
  "currency" => $rsvp_options['paypal_currency'],
  "id" => $slug
];
elseif($interval == 'monthly')
	$parray = [
  "amount" => $vars['amount'] * 100,
  "interval" => "month",
  "product" => [
    "name" => "Recurring charge, ".get_bloginfo('name')
  ],
  "currency" => strtolower($rsvp_options['paypal_currency']),
  "id" => $slug
];
	
$plans = get_option('stripe_dues_plans');
if(empty($plans))
	$plans = array();
if(!in_array($slug,$plans))
{
\Stripe\Plan::create($parray);
$plans[] = $slug;
update_option('stripe_dues_plans',$plans);
update_option('stripe_price_'.$slug,$vars['amount']);
}

$success = false;
try {
// Subscribe the customer to the plan
$subscription = \Stripe\Subscription::create(array(
    "customer" => $customer->id,
    "plan" => $slug
));
$success = true;//only set on success
}
 catch(\Stripe\Error\Card $e) {
  // Since it's a decline, \Stripe\Error\Card will be caught
  $body = $e->getJsonBody();
  $err  = $body['error'];

  print('Status is:' . $e->getHttpStatus() . "\n");
  print('Type is:' . $err['type'] . "\n");
  print('Code is:' . $err['code'] . "\n");
  // param is '' in this case
  print('Param is:' . $err['param'] . "\n");
  print('Message is:' . $err['message'] . "\n");
} catch (\Stripe\Error\RateLimit $e) {
  // Too many requests made to the API too quickly
} catch (\Stripe\Error\InvalidRequest $e) {
  // Invalid parameters were supplied to Stripe's API
} catch (\Stripe\Error\Authentication $e) {
  // Authentication with Stripe's API failed
  // (maybe you changed API keys recently)
} catch (\Stripe\Error\ApiConnection $e) {
  // Network communication with Stripe failed
} catch (\Stripe\Error\Base $e) {
  // Display a very generic error to the user, and maybe send
  // yourself an email
} catch (Exception $e) {
  // Something else happened, completely unrelated to Stripe
}
if(!$success || empty($subscription->id)) // something is wrong
	return ob_get_clean();

$vars['charge_id'] = $subscription->id;
rsvpmaker_stripe_payment_log($vars);
echo '<h1>Thank you!</h1>';
foreach($vars as $index => $value)
	printf('<div>%s: %s</div>',$index,$value);
}

function rsvpmaker_stripecharge ($atts) {
	if(is_admin())
		return;
	
	global $current_user;
	
	$vars['description'] =(!empty($atts['description'])) ? $atts['description'] : 'charge from '.get_bloginfo('name');
	$vars['paymentType'] = $paymentType = (empty($atts['paymentType'])) ? 'once' : $atts['paymentType'];
	$show =(!empty($atts['showdescription']) && ($atts['showdescription'] == 'yes')) ? true : false;
	
	if($paymentType == 'schedule')
	{
	$months = array('january','february','march','april','may','june','july','august','september','october','november','december');
	$index = date('n') - 1;
	if(isset($_GET['next']))
	{
		if($index == 11)
			$index = 0;
		else
			$index++;		
	}
	$month = $months[$index];
	$vars['amount'] = $atts[$month];
	$vars['description'] = $vars['description'].': '.ucfirst($month);
	$vars['email'] = $current_user->user_email;
	return rsvpmaker_stripe_form($vars, $show);
	}
	
	$vars['amount'] = (!empty($atts['amount'])) ? $atts['amount'] : '';
	if($paymentType != 'once')
		$vars['description'] .= ' '.$paymentType;
	return rsvpmaker_stripe_form($vars,$show);
}

function rsvpmaker_stripe_payment_log($vars) {
global $post, $current_user;
fix_timezone();
$vars['timestamp'] = date('r');
if(is_user_logged_in())
{
$vars = array('member_name'=>$current_user->display_name)+$vars;
$vars['user_id'] = $current_user->ID;
update_user_meta($current_user->ID,'rsvpmaker_stripe_payment',$vars);
}
add_post_meta($post->ID,'rsvpmaker_stripe_payment',$vars);
do_action('rsvpmaker_stripe_payment',$vars);
}

function rsvpmaker_stripe_report () {
	echo '<h1>Stripe Charges</h1>';
	
	global $wpdb;
	$sql = "SELECT * FROM $wpdb->postmeta WHERE meta_key='rsvpmaker_stripe_payment' ORDER BY meta_id DESC";
	$results = $wpdb->get_results($sql);
	foreach($results as $row) {
		echo '<p>';
		$payment = unserialize($row->meta_value);
		foreach($payment as $index => $value)
			printf('<div>%s: %s</div>',$index,$value);
		echo '</p>';
	}
}

add_action('admin_menu','rsvpmaker_stripe_report_menu',99);
function rsvpmaker_stripe_report_menu () {
if(empty(get_option('rsvpmaker_stripe_sk')))
	return;
add_submenu_page('edit.php?post_type=rsvpmaker', __("RSVPMaker Stripe Report",'rsvpmaker'), __("RSVPMaker Stripe Report",'rsvpmaker'), 'edit_rsvpmakers', "rsvpmaker_stripe_report", "rsvpmaker_stripe_report" );

//add_menu_page(__('RSVPMaker Stripe Transactions','rsvpmaker'), __('RSVPMaker Stripe Transactions','rsvpmaker'), 'manage_options','rsvpmaker_stripe_report', 'rsvpmaker_stripe_report','dashicons-products','9');
}
?>